/*
 * Copyright (c) 2005-2010 KOM – Multimedia Communications Lab
 *
 * This file is part of PeerfactSim.KOM.
 * 
 * PeerfactSim.KOM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 * 
 * PeerfactSim.KOM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with PeerfactSim.KOM.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

package de.tud.kom.p2psim.impl.util;

import java.util.HashMap;

public class IncrementableHashMap<K> {

	private HashMap<K, Integer> storage;

	public IncrementableHashMap() {
		storage = new HashMap<>();
	}

	public int get(K key) {
		return storage.get(key).intValue();
	}

	public void increment(K key) {
		if(storage.containsKey(key)) {
			Integer tmp = storage.get(key);
			storage.put(key, new Integer(tmp.intValue() + 1));
		} else {
			storage.put(key, new Integer(1));
		}
	}

	public void decrement(K key) {
		if(storage.containsKey(key)) {
			Integer tmp = storage.get(key);
			if(tmp.compareTo(new Integer(1)) == 0) {
				storage.put(key, new Integer(0));
			} else {
				storage.put(key, new Integer(tmp.intValue() - 1));
			}
		} else {
			storage.put(key, new Integer(0));
		}
	}

	public boolean containsKey(K key) {
		return storage.containsKey(key);
	}
	
	public String toString() {
		StringBuilder sb = new StringBuilder();
		for(K key: storage.keySet()) {
			sb.append(key.toString() + ": " + storage.get(key).toString() + "\n");
		}
		return sb.toString();
	}
}
